/******************************************************************************

Licensed Materials - Property of IBM 

5655-S97 

© Copyright IBM Corp. 2012 

This source material is provided "AS-IS" under the terms and
conditions of the IBM Customer Agreement and of the associated
Licensed Program Specifications documentation for CICS Transaction
Server for z/OS.

The terms and conditions of this license permit users to modify this
source material and DO NOT provide for any entitlement to defect
correction.

******************************************************************************/
package $packageName$;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.handlers.HandlerUtil;

import com.ibm.cics.core.comm.ConnectionException;
import com.ibm.cics.core.comm.IConnectable;
import com.ibm.cics.core.connections.ConnectionsPlugin;
import com.ibm.cics.zos.comm.IZOSConnection;
import com.ibm.cics.zos.model.HFSFile;
import com.ibm.cics.zos.model.IZOSConnectable;
import com.ibm.cics.zos.model.ZOSConnectable.ZOSEventObject;

public class RunUNIXFileHandler extends AbstractHandler{

	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {

		ISelection selection = HandlerUtil.getCurrentSelection(event);
		if(selection != null){
			final HFSFile hfsFile = (HFSFile) ((IStructuredSelection)selection).getFirstElement();
			IConnectable telnetConnectable = ConnectionsPlugin.getDefault().getConnectionService().getConnectable(TelnetConnection.CATEGORY);
			IConnectable zosConnectable = ConnectionsPlugin.getDefault().getConnectionService().getConnectable(IZOSConnection.CATEGORY_ID);
			ITelnetConnection connection = (ITelnetConnection) telnetConnectable.getConnection(); 
			try {
				final String result = connection.getOperation().runExecutableFile(hfsFile.getParentPath(),hfsFile.getName());
				if(zosConnectable != null){
					((IZOSConnectable)zosConnectable).signalEvent(new ZOSEventObject(hfsFile){
						private static final long serialVersionUID = -1L;
						@Override
						public String toDisplayString() {
							HFSFile file = (HFSFile)source;
							return "z/OS UNIX file=" + file.getPath() + " - executed" + System.getProperty("line.separator") + result;
						}
					});
				}
			} catch (ConnectionException e) {
				throw new ExecutionException("Unable to execute z/OS UNIX file " + hfsFile.getPath(), e);
			}
			System.out.println(hfsFile.toString());
		}
		return null;
		
	}
	
	@Override
	public boolean isHandled() {
		return true;
	}
	
	IConnectable getTelnetConnectable(){
		return ConnectionsPlugin.getDefault().getConnectionService().getConnectable(TelnetConnection.CATEGORY);
	}
	
	@Override
	public boolean isEnabled() {
		IConnectable connectable = getTelnetConnectable();
		return connectable != null && connectable.isConnected();
	}
	
}